@@ -8,6 +8,10 @@ from datagen.components.scene import Scene
 SCENE_FOLDER_NAME_PATTERNS = ["scene_*", "environment_*"]
 
 
+class CorruptedSourceError(ValueError):
+    ...
+
+
 @dataclass
 class DataSource:
     path: Path
@@ -17,13 +21,14 @@ class DataSource:
         return "identities"
 
     def init_scenes(self) -> List[Scene]:
-        scenes = [Scene(dir_) for dir_ in sorted(self.path.iterdir()) if self._matches_scene_name_pattern(dir_)]
-        assert len(scenes) > 0, f"Invalid source structure: {self.path}"
+        scenes = [Scene(path=path_) for path_ in sorted(self.path.iterdir()) if self._is_path_to_scene(path_)]
+        if len(scenes) == 0:
+            raise CorruptedSourceError(f"Corrupted source: {str(self.path)}")
         return scenes
 
     @staticmethod
-    def _matches_scene_name_pattern(dir_) -> bool:
-        return any(dir_.match(p) for p in SCENE_FOLDER_NAME_PATTERNS) and dir_.is_dir()
+    def _is_path_to_scene(path: Path) -> bool:
+        return any(path.match(pattern) for pattern in SCENE_FOLDER_NAME_PATTERNS) and path.is_dir()
 
 
 @dataclass
