@@ -159,7 +159,7 @@ class Accessory:
 
 @marshmallow_dataclass.dataclass
 class Glasses(Accessory):
-    type: ClassVar[str] = "GLASSES"
+    type: ClassVar[str] = "glasses"
     style: str
     lens_color: str
     reflectivity: float
@@ -184,8 +184,18 @@ class Glasses(Accessory):
         return self.transparency
 
 
+@marshmallow_dataclass.dataclass
+class Mask(Accessory):
+    type: ClassVar[str] = "mask"
+    style: str
+    location: str
+    mask_color: str
+    mask_texture: str
+    roughness: float
+
+
 class AccessoryField(Field):
-    ACCESSORY_TYPE_TO_CLASS = {"glasses": Glasses}
+    ACCESSORY_TYPE_TO_CLASS = {"glasses": Glasses, "mask": Mask}
 
     def _deserialize(self, accessory_dict: dict, attr, data, **kwargs) -> Accessory:
         accessory_type = accessory_dict.pop("type")
