@@ -16,4 +16,11 @@ class Keypoints:
     def rename_fields(self, in_data: dict, **kwargs) -> dict:
         in_data["coords_2d"] = (in_data.pop("keypoints_2d_coordinates"),)
         in_data["coords_3d"] = in_data.pop("keypoints_3d_coordinates")
+        in_data["is_visible"] = list(map(lambda s: s == "true", in_data.pop("is_visible")))
         return in_data
+
+
+@marshmallow_dataclass.dataclass
+class SceneKeypoints:
+    standard: Keypoints
+    dense: Keypoints
